==> kadu_1.2.orig.tar.bz2: kadu-1.2/plugins/autostatus/translations/autostatus_pl.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="pl" version="2.0">
<context>
    <name>@default</name>
    <message>
        <source>Status</source>
        <translation>Status</translation>
    </message>
    <message>
        <source>Autostatus file</source>
        <translation>Plik z automatycznymi statusami</translation>
    </message>
    <message>
        <source>Time</source>
        <translation>Czas</translation>
    </message>
    <message numerus="yes">
        <source>%n second(s)</source>
        <translation><numerusform>%n sekunda</numerusform><numerusform>%n sekundy</numerusform><numerusform>%n sekund</numerusform></translation>
    </message>
    <message>
        <source>Online</source>
        <translation>Dostępny</translation>
    </message>
    <message>
        <source>Busy</source>
        <translation>Zajęty</translation>
    </message>
    <message>
        <source>Invisible</source>
        <translation>Niewidoczny</translation>
    </message>
    <message>
        <source>Behavior</source>
        <translation>Zachowanie</translation>
    </message>
    <message>
        <source>Description</source>
        <translation>Opis</translation>
    </message>
    <message>
        <source>AutoStatus</source>
        <translation>Automatyczny status</translation>
    </message>
</context>
<context>
    <name>AutostatusActions</name>
    <message>
        <source>&amp;Autostatus</source>
        <translation>&amp;Automatyczny status</translation>
    </message>
</context>
</TS>

==> kadu_3.0~rc1.orig.tar.bz2: kadu-3.0-rc1/plugins/autostatus/translations/autostatus_pl.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="pl">
<context>
    <name>@default</name>
    <message>
        <source>Status</source>
        <translation>Status</translation>
    </message>
    <message>
        <source>Autostatus file</source>
        <translation>Plik z automatycznymi statusami</translation>
    </message>
    <message>
        <source>Time</source>
        <translation>Czas</translation>
    </message>
    <message numerus="yes">
        <source>%n second(s)</source>
        <translation>
            <numerusform>%n sekunda</numerusform>
            <numerusform>%n sekundy</numerusform>
            <numerusform>%n sekund</numerusform>
        </translation>
    </message>
    <message>
        <source>Online</source>
        <translation>Dostępny</translation>
    </message>
    <message>
        <source>Busy</source>
        <translation>Zajęty</translation>
    </message>
    <message>
        <source>Invisible</source>
        <translation>Niewidoczny</translation>
    </message>
    <message>
        <source>Behavior</source>
        <translation>Zachowanie</translation>
    </message>
    <message>
        <source>Description</source>
        <translation>Opis</translation>
    </message>
    <message>
        <source>AutoStatus</source>
        <translation>Automatyczny status</translation>
    </message>
</context>
<context>
    <name>AutostatusActions</name>
    <message>
        <source>&amp;Autostatus</source>
        <translation>&amp;Automatyczny status</translation>
    </message>
</context>
</TS>
